@@ -198,7 +198,8 @@ class Sale:
         """
         Checks if instance of store view is same as instance of sale order
         """
-        if self.magento_store_view.instance != self.magento_instance:
+        if self.magento_id and \
+                self.magento_store_view.instance != self.magento_instance:
             return False
         return True
 
@@ -522,6 +523,8 @@ class ImportOrdersStart(ModelView):
     "Import Sale Order Start View"
     __name__ = 'magento.wizard_import_orders.start'
 
+    message = fields.Text("Message", readonly=True)
+
 
 class ImportOrders(Wizard):
     """
@@ -542,6 +545,20 @@ class ImportOrders(Wizard):
 
     import_ = StateAction('sale.act_sale_form')
 
+    def default_start(self, data):
+        """
+        Sets default data for wizard
+
+        :param data: Wizard data
+        """
+        return {
+            'message': "This wizard will import all sale orders placed on " +
+                "this store view on magento after the Last Order Import " +
+                "Time. If Last Order Import Time is missing, then it will " +
+                "import all the orders from beginning of time. [This might " +
+                "be slow depending on number of orders]."
+        }
+
     def do_import_(self, action):
         """Handles the transition"""
 
@@ -563,6 +580,8 @@ class ExportOrderStatusStart(ModelView):
     "Export Order Status Start View"
     __name__ = 'magento.wizard_export_order_status.start'
 
+    message = fields.Text("Message", readonly=True)
+
 
 class ExportOrderStatus(Wizard):
     """
@@ -583,6 +602,19 @@ class ExportOrderStatus(Wizard):
 
     export_ = StateAction('sale.act_sale_form')
 
+    def default_start(self, data):
+        """
+        Sets default data for wizard
+
+        :param data: Wizard data
+        """
+        return {
+            'message': "This wizard will export orders status to magento " +
+                "for this store view. All the orders edited/updated after " +
+                "the Last Order Export Time will be exported. [NOTE: This " +
+                "feature is currently available only for Canceled Orders]"
+        }
+
     def do_export_(self, action):
         """Handles the transition"""
 
